@@ -141,6 +141,31 @@ sub Prompt($)
 	return <>;
 }
 
+
+#
+# Function to diff two files. This default implementation does nothing of
+# great use and is intended to be overridden in derived classes. It's only
+# called if you have previously called P4::Client::DoPerlDiffs() as by
+# default the diff output will go through the OutputText() interface.
+#
+sub Diff($$$$)
+{
+    my $self 		= shift;
+    my $f1		= shift;
+    my $f2		= shift;
+    my $diffFlags	= shift;
+    my $differ		= shift;
+
+    if ( $differ )
+    {
+	print( "$f1 and $f2 differ\n" );
+    }
+    else
+    {
+	print( "$f1 and $f2 are the same\n" );
+    }
+}
+
 1;
 
 __END__
@@ -232,12 +257,21 @@ derive a subclass from P4::UI and override the appropriate methods.
 
 	Prints $length bytes of $text on STDOUT
 
-
 =item C<Prompt( $prompt )>
 
 	Prints the prompt string $prompt and then reads a line
 	of input from the user returning the input line.
 
+=item C<Diff( $f1, $f2, $flags, $differ )>
+
+	Diff two files manually. The default implementation of this method
+	does nothing of any great use. It's intended to be overridden
+	in subclasses for users who want to do the diffs themselves. 
+	This method will not be invoked unless you have previously
+	called the P4::Client::DoPerlDiffs() method to specify your
+	prediliction for doing things the hard way. Otherwise diff
+	output goes out through OutputText().
+
 =back
 
 =head1 LICENCE
